@@ -1,19 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "gravatarconfigwidget.h"
-#include "misc/gravatarcache.h"
 #include "gravatarconfiguresettingsdialog.h"
-#include <KLocalizedString>
-#include <QCheckBox>
-#include <QPushButton>
-#include <QPointer>
-#include <QHBoxLayout>
 #include "gravatarsettings.h"
+#include "misc/gravatarcache.h"
+#include <KLocalizedString>
 #include <PimCommon/ConfigureImmutableWidgetUtils>
+#include <QCheckBox>
+#include <QHBoxLayout>
+#include <QPointer>
+#include <QPushButton>
 
 using namespace Gravatar;
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
@@ -33,7 +33,7 @@ GravatarConfigWidget::GravatarConfigWidget(QWidget *parent)
     : QWidget(parent)
     , d(new Gravatar::GravatarConfigWidgetPrivate)
 {
-    auto *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
     d->mEnableGravatarSupport = new QCheckBox(i18n("Enable Gravatar Support"));
